<?php

/**
 * Preprocess all templates.
 */
function amptheme_preprocess(&$vars, $hook) {
  $vars['amptheme_path_file'] = DRUPAL_ROOT . '/' . drupal_get_path('theme', 'amptheme');
}

/**
 * Implements hook_page_alter().
 */
function amptheme_page_alter(&$page) {
  // Remove the toolbar from page_top
  if(isset($page['page_top']['toolbar'])) {
    unset($page['page_top']['toolbar']);
  }

  // Remove all script tags on elements directly within a region.
  foreach ($page as $region_key => $region) {
    if (is_array($region)) {
      foreach ($region as $item_key => $item) {
        if (is_array($item) && isset($item['#tag']) && $item['#tag'] == 'script') {
          unset($page[$region_key][$item_key]);
        }
      }
    }
  }
}

/**
 * Implements hook_html_head_alter().
 */
function amptheme_html_head_alter(&$head_elements) {
  // Remove all script tags from $head except amp scripts.
  foreach ($head_elements as $key => $element) {
    if (isset($element['#tag']) && $element['#tag'] == 'script') {
      if (isset($element['#attributes']) && isset($element['#attributes']['src']) &&
        strpos($element['#attributes']['src'], 'cdn.ampproject.org') !== FALSE) {
        continue;
      }
      else {
        unset($head_elements[$key]);
      }
    }
  }

  // We will manually set this in the template to control source order.
  if (isset($head_elements['system_meta_content_type'])) {
    unset($head_elements['system_meta_content_type']);
  }
}

/**
 * Implements hook_js_alter().
 *
 */
function amptheme_js_alter(&$javascript) {
  // Remove all JS: only amp component JS added to html head is allowed.
  foreach (array_keys($javascript) as $key) {
    unset($javascript[$key]);
  }
}

/**
* Implements hook_preprocess_html() for HTML document templates.
*/
function amptheme_preprocess_html(&$variables) {

  $viewport = array(
    '#tag' => 'meta',
    '#attributes' => array(
      'name' => 'viewport',
      'content' => 'width=device-width,minimum-scale=1,initial-scale=1',
    ),
  );

  drupal_add_html_head($viewport, 'viewport');

  // Set default date published of now.
  $variables['date_published'] = date(DATE_ATOM, time());

  // Check if we have a node.
  if (!empty($node) && $node = menu_get_object()) {
    // Set the date published to the creation date of the node.
    if ($date_published = date(DATE_ATOM, $node->created)) {
      $variables['date_published'] = $date_published;
    }
  }

  // Set the url of the theme logo if it exists.
  $variables['logo_url'] = '';
  if (!empty($logo_url = theme_get_setting('logo'))) {
    $headers=get_headers($logo_url);
    if (stripos($headers[0],"200 OK")?true:false) {
      $variables['logo_url'] = $logo_url;
    }
  }
}

/**
* Implements hook_preprocess_page() for page templates.
*/
function amptheme_preprocess_page(&$variables) {
  if (!empty($variables['logo'])) {
    // Create logo path relative to files directory.
    $logo_url = parse_url($variables['logo']);
    $logo_path = $logo_url['path'];
    if (substr($logo_path, 0, strlen(base_path())) == base_path()) {
      $logo_path = substr($logo_path, strlen(base_path()));
    }
    $files_dir = variable_get('file_public_path', conf_path() . '/files');
    if (substr($logo_path, 0, strlen($files_dir)) == $files_dir) {
      $logo_path = substr($logo_path, strlen($files_dir));
    }

    // Create normalized logo URI.
    $logo_uri = file_stream_wrapper_uri_normalize(file_build_uri($logo_path));

    // Get height and width of logo.
    $logo_info = image_get_info($logo_uri);
    $variables['logo_height'] = $logo_info['height'];
    $variables['logo_width'] = $logo_info['width'];
  }
}

/**
 * Implements hook_preprocess_node() for node templates.
 */
function amptheme_preprocess_node(&$variables) {
  // Remove RDF properties incompatible with AMP specification.
  if (isset($variables['attributes_array']['about'])) {
    unset($variables['attributes_array']['about']);
  }
  if (isset($variables['attributes_array']['typeof'])) {
    unset($variables['attributes_array']['typeof']);
  }
  if (isset($variables['title_suffix']['rdf_meta_title'])) {
    unset($variables['title_suffix']['rdf_meta_title']);
  }
  if (isset($variables['title_suffix']['rdf_meta_comment_count'])) {
    unset($variables['title_suffix']['rdf_meta_comment_count']);
  }
  if (isset($variables['rdf_mapping'])) {
    unset($variables['rdf_mapping']);
  }
  if (isset($variables['rdf_template_variable_attributes_array'])) {
    unset($variables['rdf_template_variable_attributes_array']);
  }
}

/**
 * Implements hook_preprocess_field() for field templates.
 */
function amptheme_preprocess_field(&$variables) {
  // Remove RDF properties incompatible with AMP specification.
  $element = $variables['element'];
  foreach ($element['#items'] as $delta => $item) {
    if (isset($variables['item_attributes_array'][$delta]['property'])) {
      unset($variables['item_attributes_array'][$delta]['property']);
    }
    if (isset($variables['item_attributes_array'][$delta]['content'])) {
      unset($variables['item_attributes_array'][$delta]['content']);
    }
    if (isset($variables['item_attributes_array'][$delta]['datatype'])) {
      unset($variables['item_attributes_array'][$delta]['datatype']);
    }
    if (isset($variables['item_attributes_array'][$delta]['resource'])) {
      unset($variables['item_attributes_array'][$delta]['resource']);
    }
  }
}

/**
 * Implements hook_preprocess_user_profile() for user profile templates.
 */
function amptheme_preprocess_user_profile(&$variables) {
  // Remove RDF properties incompatible with AMP specification.
  if (isset($variables['attributes_array']['about'])) {
    unset($variables['attributes_array']['about']);
  }
  if (isset($variables['attributes_array']['typeof'])) {
    unset($variables['attributes_array']['typeof']);
  }
}

/**
 * Implements hook_preprocess_username() for username templates.
 */
function amptheme_preprocess_username(&$variables) {
  // Remove RDF properties incompatible with AMP specification.
  if (isset($variables['attributes_array']['xml:lang'])) {
    unset($variables['attributes_array']['xml:lang']);
  }
  if (isset($variables['attributes_array']['about'])) {
    unset($variables['attributes_array']['about']);
  }
  if (isset($variables['attributes_array']['typeof'])) {
    unset($variables['attributes_array']['typeof']);
  }
  if (isset($variables['attributes_array']['property'])) {
    unset($variables['attributes_array']['property']);
  }
  if (isset($variables['attributes_array']['datatype'])) {
    unset($variables['attributes_array']['datatype']);
  }
}

/**
 * Implements hook_preprocess_comment() for comment templates.
 */
function amptheme_preprocess_comment(&$variables) {
  // Remove RDF properties incompatible with AMP specification.
  if (isset($variables['attributes_array']['about'])) {
    unset($variables['attributes_array']['about']);
  }
  if (isset($variables['attributes_array']['typeof'])) {
    unset($variables['attributes_array']['typeof']);
  }
  if (isset($variables['title_attributes_array']['property'])) {
    unset($variables['title_attributes_array']['property']);
  }
  if (isset($variables['title_attributes_array']['datatype'])) {
    unset($variables['title_attributes_array']['datatype']);
  }
}


/**
 * Returns AMP HTML for an image.
 *
 * Overrides theme_image in order to return the amp-img element.
 *
 * @param $variables
 *   An associative array containing:
 *   - path: Either the path of the image file (relative to base_path()) or a
 *     full URL.
 *   - width: The width of the image (if known).
 *   - height: The height of the image (if known).
 *   - alt: The alternative text for text-based browsers. HTML 4 and XHTML 1.0
 *     always require an alt attribute. The HTML 5 draft allows the alt
 *     attribute to be omitted in some cases. Therefore, this variable defaults
 *     to an empty string, but can be set to NULL for the attribute to be
 *     omitted. Usually, neither omission nor an empty string satisfies
 *     accessibility requirements, so it is strongly encouraged for code
 *     calling theme('image') to pass a meaningful value for this variable.
 *     - http://www.w3.org/TR/REC-html40/struct/objects.html#h-13.8
 *     - http://www.w3.org/TR/xhtml1/dtds.html
 *     - http://dev.w3.org/html5/spec/Overview.html#alt
 *   - title: The title text is displayed when the image is hovered in some
 *     popular browsers.
 *   - attributes: Associative array of attributes to be placed in the img tag.
 */
function amptheme_image($variables) {
  // Remove RDF properties incompatible with AMP specification.
  if (isset($variables['attributes']['typeof'])) {
    unset($variables['attributes']['typeof']);
  }

  $attributes = $variables['attributes'];
  $attributes['src'] = file_create_url($variables['path']);

  foreach (array('width', 'height', 'alt', 'title') as $key) {

    if (isset($variables[$key])) {
      if (empty($attributes[$key])) {
        $attributes[$key] = $variables[$key];
      }
    }
  }

  return '<amp-img' . drupal_attributes($attributes) . ' />';
}
